# ExternallyManagedBy

An enum field on the Subscription object to indicate the name of a third-party store. This field is used to represent subscriptions created through third-party stores. 

## Enum

* `AMAZON` (value: `'Amazon'`)

* `APPLE` (value: `'Apple'`)

* `GOOGLE` (value: `'Google'`)

* `ROKU` (value: `'Roku'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


